pub enum CommerceIntentError {
InvalidField {
field: &'static str,
reason: String,
},
Serialization(Error),
Canonicalization(String),
AmountExceedsLimit {
amount: u64,
max_total: u64,
},
IntentExpired {
executed_at: u64,
expires_at: u64,
},
CurrencyMismatch {
expected: String,
actual: String,
},
MerchantMismatch {
expected: String,
actual: String,
},
PayeeMismatch {
expected: String,
actual: String,
},
ShippingCountryMismatch {
expected: String,
actual: String,
},
UnauthorizedSku {
sku: String,
},
UnauthorizedCategory {
category: String,
},
}Expand description
Errors that can occur when handling commerce intents and receipts.
Variants
InvalidField
A field failed validation.
Serialization(Error)
JSON serialization failed.
Canonicalization(String)
Canonicalization failed.
AmountExceedsLimit
The execution exceeded the authorized amount.
IntentExpired
The execution happened after the intent expired.
CurrencyMismatch
The execution currency does not match the intent currency.
MerchantMismatch
The execution merchant does not match the authorized merchant.
PayeeMismatch
The execution payee does not match the authorized payee.
ShippingCountryMismatch
The execution shipping country does not match the authorized country.
An executed SKU is outside the authorized scope.
Fields
An executed category is outside the authorized scope.
Fields